insertAll method
Inserts all elements of iterable at position index in the list.
Elements in iterable must be valid and not nullable for the PbList type.
Implementation
@override
void insertAll(int index, Iterable<E> iterable) {
iterable.forEach(check);
_wrappedList.insertAll(index, iterable);
}