setAll method
Overwrites elements of this with elements of iterable starting at
position index in the list.
Elements in iterable must be valid and not nullable for the PbList type.
Implementation
@override
void setAll(int index, Iterable<E> iterable) {
iterable.forEach(check);
_wrappedList.setAll(index, iterable);
}